@@ -52,14 +52,14 @@ extern "C"
 
 // KDE includes.
 
-#include <kconfig.h>
-#include <klocale.h>
-#include <kdeversion.h>
-#include <kmessagebox.h>
+#include <tdeconfig.h>
+#include <tdelocale.h>
+#include <tdeversion.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
-#include <kio/netaccess.h>
-#include <kio/global.h>
-#include <kio/job.h>
+#include <tdeio/netaccess.h>
+#include <tdeio/global.h>
+#include <tdeio/job.h>
 #include <kdirwatch.h>
 
 // Local includes.
@@ -113,9 +113,9 @@ public:
 
     KDirWatch        *dirWatch;
 
-    KIO::TransferJob *albumListJob;
-    KIO::TransferJob *dateListJob;
-    KIO::TransferJob *tagListJob;
+    TDEIO::TransferJob *albumListJob;
+    TDEIO::TransferJob *dateListJob;
+    TDEIO::TransferJob *tagListJob;
 
     PAlbum           *rootPAlbum;
     TAlbum           *rootTAlbum;
@@ -258,7 +258,7 @@ void AlbumManager::setLibraryPath(const TQString& path, SplashScreen *splash)
     TQString dbPath = cleanPath + "/digikam3.db";
 
 #ifdef NFS_HACK
-    dbPath = locateLocal("appdata", KIO::encodeFileName(TQDir::cleanDirPath(dbPath)));
+    dbPath = locateLocal("appdata", TDEIO::encodeFileName(TQDir::cleanDirPath(dbPath)));
 #endif
 
     d->db->setDBPath(dbPath);
@@ -277,7 +277,7 @@ void AlbumManager::setLibraryPath(const TQString& path, SplashScreen *splash)
 
         // Copy an existing locale from the settings file (used < 0.8)
         // to the database.
-        KConfig* config = KGlobal::config();
+        TDEConfig* config = TDEGlobal::config();
         config->setGroup("General Settings");
         if (config->hasKey("Locale"))
         {
@@ -352,7 +352,7 @@ void AlbumManager::setLibraryPath(const TQString& path, SplashScreen *splash)
 
     // -- Check if we need to do scanning -------------------------------------
 
-    KConfig* config = KGlobal::config();
+    TDEConfig* config = TDEGlobal::config();
     config->setGroup("General Settings");
     if (config->readBoolEntry("Scan At Start", true) ||
         d->db->getSetting("Scanned").isEmpty())
@@ -520,7 +520,7 @@ void AlbumManager::scanPAlbums()
     if (!AlbumSettings::instance()->getShowFolderTreeViewItemsCount())
         return;
         
-    // List albums using kioslave
+    // List albums using tdeioslave
 
     if (d->albumListJob)
     {
@@ -541,15 +541,15 @@ void AlbumManager::scanPAlbums()
     ds << 0; // recursive sub-album (not needed here)
     ds << 0; // recursive sub-tags (not needed here)
         
-    d->albumListJob = new KIO::TransferJob(u, KIO::CMD_SPECIAL,
+    d->albumListJob = new TDEIO::TransferJob(u, TDEIO::CMD_SPECIAL,
                                            ba, TQByteArray(), false);
     d->albumListJob->addMetaData("folders", "yes");
 
-    connect(d->albumListJob, TQT_SIGNAL(result(KIO::Job*)),
-            this, TQT_SLOT(slotAlbumsJobResult(KIO::Job*)));
+    connect(d->albumListJob, TQT_SIGNAL(result(TDEIO::Job*)),
+            this, TQT_SLOT(slotAlbumsJobResult(TDEIO::Job*)));
 
-    connect(d->albumListJob, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(slotAlbumsJobData(KIO::Job*, const TQByteArray&)));
+    connect(d->albumListJob, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQT_SLOT(slotAlbumsJobData(TDEIO::Job*, const TQByteArray&)));
 }
 
 void AlbumManager::scanTAlbums()
@@ -669,7 +669,7 @@ void AlbumManager::scanTAlbums()
     if (!AlbumSettings::instance()->getShowFolderTreeViewItemsCount())
         return;
         
-    // List tags using kioslave
+    // List tags using tdeioslave
 
     if (d->tagListJob)
     {
@@ -690,15 +690,15 @@ void AlbumManager::scanTAlbums()
     ds << 0; // recursive sub-album (not needed here)
     ds << 0; // recursive sub-tags (not needed here)
         
-    d->tagListJob = new KIO::TransferJob(u, KIO::CMD_SPECIAL,
+    d->tagListJob = new TDEIO::TransferJob(u, TDEIO::CMD_SPECIAL,
                                          ba, TQByteArray(), false);
     d->tagListJob->addMetaData("folders", "yes");
 
-    connect(d->tagListJob, TQT_SIGNAL(result(KIO::Job*)),
-            this, TQT_SLOT(slotTagsJobResult(KIO::Job*)));
+    connect(d->tagListJob, TQT_SIGNAL(result(TDEIO::Job*)),
+            this, TQT_SLOT(slotTagsJobResult(TDEIO::Job*)));
 
-    connect(d->tagListJob, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(slotTagsJobData(KIO::Job*, const TQByteArray&)));
+    connect(d->tagListJob, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQT_SLOT(slotTagsJobData(TDEIO::Job*, const TQByteArray&)));
 }
 
 void AlbumManager::scanSAlbums()
@@ -739,7 +739,7 @@ void AlbumManager::scanSAlbums()
 
 void AlbumManager::scanDAlbums()
 {
-    // List dates using kioslave
+    // List dates using tdeioslave
 
     if (d->dateListJob)
     {
@@ -760,15 +760,15 @@ void AlbumManager::scanDAlbums()
     ds << 0; // recursive sub-album (not needed here)
     ds << 0; // recursive sub-tags (not needed here)
     
-    d->dateListJob = new KIO::TransferJob(u, KIO::CMD_SPECIAL,
+    d->dateListJob = new TDEIO::TransferJob(u, TDEIO::CMD_SPECIAL,
                                           ba, TQByteArray(), false);
     d->dateListJob->addMetaData("folders", "yes");
 
-    connect(d->dateListJob, TQT_SIGNAL(result(KIO::Job*)),
-            this, TQT_SLOT(slotDatesJobResult(KIO::Job*)));
+    connect(d->dateListJob, TQT_SIGNAL(result(TDEIO::Job*)),
+            this, TQT_SLOT(slotDatesJobResult(TDEIO::Job*)));
 
-    connect(d->dateListJob, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(slotDatesJobData(KIO::Job*, const TQByteArray&)));
+    connect(d->dateListJob, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQT_SLOT(slotDatesJobData(TDEIO::Job*, const TQByteArray&)));
 }
 
 AlbumList AlbumManager::allPAlbums() const
@@ -1455,7 +1455,7 @@ void AlbumManager::refreshItemHandler(const KURL::List& itemList)
         d->itemHandler->refreshItems(itemList);
 }
 
-void AlbumManager::slotAlbumsJobResult(KIO::Job* job)
+void AlbumManager::slotAlbumsJobResult(TDEIO::Job* job)
 {
     d->albumListJob = 0;
 
@@ -1466,7 +1466,7 @@ void AlbumManager::slotAlbumsJobResult(KIO::Job* job)
     }
 }
 
-void AlbumManager::slotAlbumsJobData(KIO::Job*, const TQByteArray& data)
+void AlbumManager::slotAlbumsJobData(TDEIO::Job*, const TQByteArray& data)
 {
     if (data.isEmpty())
         return;
@@ -1478,7 +1478,7 @@ void AlbumManager::slotAlbumsJobData(KIO::Job*, const TQByteArray& data)
     emit signalPAlbumsDirty(albumsStatMap);
 }
 
-void AlbumManager::slotTagsJobResult(KIO::Job* job)
+void AlbumManager::slotTagsJobResult(TDEIO::Job* job)
 {
     d->tagListJob = 0;
 
@@ -1489,7 +1489,7 @@ void AlbumManager::slotTagsJobResult(KIO::Job* job)
     }
 }
 
-void AlbumManager::slotTagsJobData(KIO::Job*, const TQByteArray& data)
+void AlbumManager::slotTagsJobData(TDEIO::Job*, const TQByteArray& data)
 {
     if (data.isEmpty())
         return;
@@ -1501,7 +1501,7 @@ void AlbumManager::slotTagsJobData(KIO::Job*, const TQByteArray& data)
     emit signalTAlbumsDirty(tagsStatMap);
 }
 
-void AlbumManager::slotDatesJobResult(KIO::Job* job)
+void AlbumManager::slotDatesJobResult(TDEIO::Job* job)
 {
     d->dateListJob = 0;
 
@@ -1514,7 +1514,7 @@ void AlbumManager::slotDatesJobResult(KIO::Job* job)
     emit signalAllDAlbumsLoaded();
 }
 
-void AlbumManager::slotDatesJobData(KIO::Job*, const TQByteArray& data)
+void AlbumManager::slotDatesJobData(TDEIO::Job*, const TQByteArray& data)
 {
     if (data.isEmpty())
         return;
