@@ -28,7 +28,7 @@
 
 #include <tqobject.h>
 
-namespace KIO
+namespace TDEIO
 {
 class Job;
 }
@@ -39,17 +39,16 @@ namespace DIO
 class Watch : public TQObject
 {
     Q_OBJECT
-  TQ_OBJECT
     
 public:
 
-    Watch(KIO::Job* job);
+    Watch(TDEIO::Job* job);
 
     static uint m_runCount;
     
 private slots:
 
-   void slotDone(KIO::Job* job);
+   void slotDone(TDEIO::Job* job);
 };
 
 } // namespace DIO
