@@ -41,7 +41,7 @@
 // KDE includes.
 
 #include <kcursor.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 
 // Local includes.
 
@@ -1111,7 +1111,7 @@ void IconView::contentsMouseMoveEvent(TQMouseEvent* e)
             }
         }
 
-        if (KGlobalSettings::changeCursorOverIcon())
+        if (TDEGlobalSettings::changeCursorOverIcon())
         {
             if (item && item->clickToOpenRect().contains(e->pos()))
                 setCursor(KCursor::handCursor());
@@ -1259,7 +1259,7 @@ void IconView::contentsMouseReleaseEvent(TQMouseEvent* e)
             d->anchorItem = item;
             if (prevCurrItem)
                 prevCurrItem->repaint();
-            if (KGlobalSettings::singleClick())
+            if (TDEGlobalSettings::singleClick())
             {
                 if (item->clickToOpenRect().contains(e->pos()))
                 {
@@ -1282,7 +1282,7 @@ void IconView::contentsWheelEvent(TQWheelEvent* e)
 
 void IconView::contentsMouseDoubleClickEvent(TQMouseEvent *e)
 {
-    if (KGlobalSettings::singleClick())
+    if (TDEGlobalSettings::singleClick())
         return;
 
     IconItem *item = findItem(e->pos());
