@@ -88,8 +88,8 @@ public:
     virtual TQDateTime time( KIPI::TimeSpec spec );
     virtual void setTime( const TQDateTime& time, KIPI::TimeSpec spec = KIPI::FromInfo );
     
-    virtual TQMap<TQString, TQVariant> attributes();                    
-    virtual void addAttributes(const TQMap<TQString, TQVariant>& res);
+    virtual TQStringVariantMap attributes();
+    virtual void addAttributes(const TQStringVariantMap& res);
     virtual void clearAttributes();
     
     virtual int  angle();
