@@ -31,7 +31,7 @@
 
 // KDE includes.
 
-#include <khtml_part.h>
+#include <tdehtml_part.h>
 
 // Local includes.
 
@@ -40,10 +40,9 @@
 namespace Digikam
 {
 
-class DIGIKAM_EXPORT WelcomePageView : public KHTMLPart
+class DIGIKAM_EXPORT WelcomePageView : public TDEHTMLPart
 {
     Q_OBJECT
-  TQ_OBJECT
 
 public:
 
