@@ -32,12 +32,12 @@
 
 // KDE includes.
 
-#include <kaboutdata.h>
-#include <kapplication.h>
+#include <tdeaboutdata.h>
+#include <tdeapplication.h>
 #include <kcolorbutton.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kseparator.h>
 #include <kstandarddirs.h>
 
@@ -204,7 +204,7 @@ void BorderTool::readSettings()
     m_secondColorButton->blockSignals(true);
     m_preserveAspectRatio->blockSignals(true);
 
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup("border Tool");
 
     m_borderType->setCurrentItem(config->readNumEntry("Border Type", m_borderType->defaultItem()));
@@ -237,7 +237,7 @@ void BorderTool::readSettings()
 
 void BorderTool::writeSettings()
 {
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup("border Tool");
 
     config->writeEntry("Border Type", m_borderType->currentItem());
@@ -646,9 +646,9 @@ TQString BorderTool::getBorderPath(int border)
           return TQString();
        }
 
-    KGlobal::dirs()->addResourceType(pattern.ascii(), KGlobal::dirs()->kde_default("data") +
+    TDEGlobal::dirs()->addResourceType(pattern.ascii(), TDEGlobal::dirs()->kde_default("data") +
                                      "digikam/data");
-    return (KGlobal::dirs()->findResourceDir(pattern.ascii(), pattern + ".png") + pattern + ".png" );
+    return (TDEGlobal::dirs()->findResourceDir(pattern.ascii(), pattern + ".png") + pattern + ".png" );
 }
 
 void BorderTool::slotPreserveAspectRatioToggled(bool b)
