@@ -34,12 +34,12 @@
 // KDE includes.
 
 #include <kseparator.h>
-#include <klocale.h>
-#include <kaboutdata.h>
+#include <tdelocale.h>
+#include <tdeaboutdata.h>
 #include <kiconloader.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kstandarddirs.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <knuminput.h>
 #include <kcolorbutton.h>
 
@@ -66,11 +66,11 @@ ImageEffect_Border::ImageEffect_Border(TQWidget* parent)
     
     TQString whatsThis;
     
-    KAboutData* about = new KAboutData("digikam",
+    TDEAboutData* about = new TDEAboutData("digikam",
                                        I18N_NOOP("Add Border"), 
                                        digikam_version,
                                        I18N_NOOP("A digiKam image plugin to add a border around an image."),
-                                       KAboutData::License_GPL,
+                                       TDEAboutData::License_GPL,
                                        "(c) 2005, Gilles Caulier\n"
                                        "(c) 2006-2008, Gilles Caulier and Marcel Wiesweg",
                                        0,
@@ -204,7 +204,7 @@ void ImageEffect_Border::readUserSettings(void)
     m_secondColorButton->blockSignals(true);
     m_preserveAspectRatio->blockSignals(true);
 
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup("border Tool Dialog");
     
     m_borderType->setCurrentItem(config->readNumEntry("Border Type", Border::SolidBorder));
@@ -237,7 +237,7 @@ void ImageEffect_Border::readUserSettings(void)
     
 void ImageEffect_Border::writeUserSettings(void)
 {
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup("border Tool Dialog");
 
     config->writeEntry("Border Type", m_borderType->currentItem());
@@ -644,9 +644,9 @@ TQString ImageEffect_Border::getBorderPath(int border)
           return TQString();
        }
     
-    KGlobal::dirs()->addResourceType(pattern.ascii(), KGlobal::dirs()->kde_default("data") +
+    TDEGlobal::dirs()->addResourceType(pattern.ascii(), TDEGlobal::dirs()->kde_default("data") +
                                      "digikam/data");
-    return (KGlobal::dirs()->findResourceDir(pattern.ascii(), pattern + ".png") + pattern + ".png" );
+    return (TDEGlobal::dirs()->findResourceDir(pattern.ascii(), pattern + ".png") + pattern + ".png" );
 }
 
 void ImageEffect_Border::slotPreserveAspectRatioToggled(bool b)
