@@ -56,19 +56,19 @@
 
 // KDE includes.
 
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kcursor.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <knuminput.h>
-#include <kmessagebox.h>
-#include <kselect.h>
-#include <kfiledialog.h>
-#include <kglobalsettings.h>
-#include <kaboutdata.h>
+#include <tdemessagebox.h>
+#include <tdeselect.h>
+#include <tdefiledialog.h>
+#include <tdeglobalsettings.h>
+#include <tdeaboutdata.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kapplication.h>
-#include <kpopupmenu.h>
+#include <tdeapplication.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
 
 // Local includes.
@@ -96,11 +96,11 @@ ChannelMixerDialog::ChannelMixerDialog(TQWidget* parent)
 
     // About data and help button.
 
-    KAboutData* about = new KAboutData("digikam",
+    TDEAboutData* about = new TDEAboutData("digikam",
                                        I18N_NOOP("Color Channel Mixer"),
                                        digikam_version,
                                        I18N_NOOP("An image color channel mixer plugin for digiKam."),
-                                       KAboutData::License_GPL,
+                                       TDEAboutData::License_GPL,
                                        "(c) 2005-2008, Gilles Caulier",
                                        0,
                                        "http://www.digikam.org");
@@ -147,16 +147,16 @@ ChannelMixerDialog::ChannelMixerDialog(TQWidget* parent)
     TQPushButton *linHistoButton = new TQPushButton( m_scaleBG );
     TQToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
     m_scaleBG->insert(linHistoButton, Digikam::HistogramWidget::LinScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    TDEGlobal::dirs()->addResourceType("histogram-lin", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
     linHistoButton->setPixmap( TQPixmap( directory + "histogram-lin.png" ) );
     linHistoButton->setToggleButton(true);
 
     TQPushButton *logHistoButton = new TQPushButton( m_scaleBG );
     TQToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
     m_scaleBG->insert(logHistoButton, Digikam::HistogramWidget::LogScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    TDEGlobal::dirs()->addResourceType("histogram-log", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
     logHistoButton->setPixmap( TQPixmap( directory + "histogram-log.png" ) );
     logHistoButton->setToggleButton(true);
 
@@ -525,7 +525,7 @@ void ChannelMixerDialog::slotScaleChanged(int scale)
 
 void ChannelMixerDialog::readUserSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("channelmixer Tool Dialog");
 
     m_channelCB->setCurrentItem(config->readNumEntry("Histogram Channel", 0));    // Luminosity.
@@ -559,7 +559,7 @@ void ChannelMixerDialog::readUserSettings()
 
 void ChannelMixerDialog::writeUserSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("channelmixer Tool Dialog");
     config->writeEntry("Histogram Channel", m_channelCB->currentItem());
     config->writeEntry("Histogram Scale", m_scaleBG->selectedId());
@@ -626,7 +626,7 @@ void ChannelMixerDialog::slotUser3()
     int currentOutputChannel;
     bool monochrome;
     
-    loadGainsFileUrl = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
+    loadGainsFileUrl = KFileDialog::getOpenURL(TDEGlobalSettings::documentPath(),
                                             TQString( "*" ), this,
                                             TQString( i18n("Select Gimp Gains Mixer File to Load")) );
     if( loadGainsFileUrl.isEmpty() )
@@ -711,7 +711,7 @@ void ChannelMixerDialog::slotUser2()
     KURL saveGainsFileUrl;
     FILE *fp = 0L;
     
-    saveGainsFileUrl = KFileDialog::getSaveURL(KGlobalSettings::documentPath(),
+    saveGainsFileUrl = KFileDialog::getSaveURL(TDEGlobalSettings::documentPath(),
                                                TQString( "*" ), this,
                                                TQString( i18n("Gimp Gains Mixer File to Save")) );
     if( saveGainsFileUrl.isEmpty() )
