@@ -59,7 +59,7 @@
 
 #include <kstandarddirs.h>
 #include <kcursor.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 
 // Local includes.
 
