@@ -36,17 +36,17 @@
 
 // KDE includes.
 
-#include <kaboutdata.h>
+#include <tdeaboutdata.h>
 #include <kcursor.h>
-#include <klocale.h>
-#include <kapplication.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
 #include <kseparator.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kurl.h>
 #include <kiconloader.h>
-#include <kfiledialog.h>
-#include <kglobalsettings.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdeglobalsettings.h>
+#include <tdemessagebox.h>
 
 // LibKDcraw includes.
 
@@ -375,7 +375,7 @@ void SharpenTool::slotSharpMethodActived(int w)
 
 void SharpenTool::readSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("sharpen Tool");
     m_radiusInput->blockSignals(true);
     m_radiusInput2->blockSignals(true);
@@ -415,7 +415,7 @@ void SharpenTool::readSettings()
 
 void SharpenTool::writeSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("sharpen Tool");
     config->writeEntry("SimpleSharpRadiusAjustment", m_radiusInput->value());
     config->writeEntry("UnsharpMaskRadiusAjustment", m_radiusInput2->value());
@@ -678,7 +678,7 @@ void SharpenTool::putFinalData()
 
 void SharpenTool::slotLoadSettings()
 {
-    KURL loadRestorationFile = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
+    KURL loadRestorationFile = KFileDialog::getOpenURL(TDEGlobalSettings::documentPath(),
                                TQString( "*" ), TQT_TQWIDGET(kapp->activeWindow()),
                                TQString( i18n("Photograph Refocus Settings File to Load")) );
     if ( loadRestorationFile.isEmpty() )
@@ -714,7 +714,7 @@ void SharpenTool::slotLoadSettings()
 
 void SharpenTool::slotSaveAsSettings()
 {
-    KURL saveRestorationFile = KFileDialog::getSaveURL(KGlobalSettings::documentPath(),
+    KURL saveRestorationFile = KFileDialog::getSaveURL(TDEGlobalSettings::documentPath(),
                                TQString( "*" ), TQT_TQWIDGET(kapp->activeWindow()),
                                TQString( i18n("Photograph Refocus Settings File to Save")) );
     if ( saveRestorationFile.isEmpty() )
