@@ -30,12 +30,12 @@
 #include "imageplugin.h"
 #include "digikam_export.h"
 
-class KAction;
+class TDEAction;
 
 class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_Infrared : public Digikam::ImagePlugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 
@@ -51,7 +51,7 @@ private slots:
 
 private:
 
-    KAction *m_infraredAction;
+    TDEAction *m_infraredAction;
 };
 
 #endif /* IMAGEPLUGIN_INFRARED_H */
