@@ -237,7 +237,7 @@ FontChooserWidget::FontChooserWidget(TQWidget *parent, const char *name,
         TQString sizeIsRelativeCBToolTipText =
         i18n("Font size<br><i>fixed</i> or <i>relative</i><br>to environment");
         TQString sizeIsRelativeCBWhatsThisText =
-        i18n("Here you can switch between fixed a font size and a font size "
+        i18n("Here you can switch between a fixed font size and a font size "
              "to be calculated dynamically and adjusted to any changing "
              "environment (e.g. widget dimensions, paper size)." );
         sizeIsRelativeCheckBox = new TQCheckBox( sizeIsRelativeCBText,
