@@ -37,7 +37,7 @@
 
 #include <kstandarddirs.h>
 #include <kcursor.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 
 // Digikam includes.
 
