@@ -36,16 +36,16 @@
 
 // KDE includes.
 
-#include <klocale.h>
-#include <kaboutdata.h>
+#include <tdelocale.h>
+#include <tdeaboutdata.h>
 #include <kiconloader.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kstandarddirs.h>
 #include <knuminput.h>
-#include <kfiledialog.h>
-#include <kglobalsettings.h>
-#include <kmessagebox.h>
-#include <kconfig.h>
+#include <tdefiledialog.h>
+#include <tdeglobalsettings.h>
+#include <tdemessagebox.h>
+#include <tdeconfig.h>
 
 // Local includes.
 
@@ -68,11 +68,11 @@ ImageEffect_NoiseReduction::ImageEffect_NoiseReduction(TQWidget* parent)
 {
     TQString whatsThis;
 
-    KAboutData* about = new KAboutData("digikam",
+    TDEAboutData* about = new TDEAboutData("digikam",
                                        I18N_NOOP("Noise Reduction"),
                                        digikam_version,
                                        I18N_NOOP("A noise reduction image filter plugin for digiKam."),
-                                       KAboutData::License_GPL,
+                                       TDEAboutData::License_GPL,
                                        "(c) 2004-2008, Gilles Caulier",
                                        0,
                                        "http://www.digikam.org");
@@ -316,7 +316,7 @@ void ImageEffect_NoiseReduction::renderingFinished()
 
 void ImageEffect_NoiseReduction::readUserSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("noisereduction Tool Dialog");
     m_radiusInput->setEnabled(true);
     m_lumToleranceInput->setEnabled(true);
@@ -354,7 +354,7 @@ void ImageEffect_NoiseReduction::readUserSettings()
 
 void ImageEffect_NoiseReduction::writeUserSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("noisereduction Tool Dialog");
     config->writeEntry("RadiusAjustment", m_radiusInput->value());
     config->writeEntry("LumToleranceAjustment", m_lumToleranceInput->value());
@@ -477,7 +477,7 @@ void ImageEffect_NoiseReduction::putFinalData(void)
 
 void ImageEffect_NoiseReduction::slotUser3()
 {
-    KURL loadRestorationFile = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
+    KURL loadRestorationFile = KFileDialog::getOpenURL(TDEGlobalSettings::documentPath(),
                                TQString( "*" ), this,
                                TQString( i18n("Photograph Noise Reduction Settings File to Load")) );
     if ( loadRestorationFile.isEmpty() )
@@ -519,7 +519,7 @@ void ImageEffect_NoiseReduction::slotUser3()
 
 void ImageEffect_NoiseReduction::slotUser2()
 {
-    KURL saveRestorationFile = KFileDialog::getSaveURL(KGlobalSettings::documentPath(),
+    KURL saveRestorationFile = KFileDialog::getSaveURL(TDEGlobalSettings::documentPath(),
                                TQString( "*" ), this,
                                TQString( i18n("Photograph Noise Reduction Settings File to Save")) );
     if ( saveRestorationFile.isEmpty() )
