@@ -39,17 +39,17 @@
 // KDE includes.
 
 #include <kcursor.h>
-#include <klocale.h>
-#include <kaboutdata.h>
+#include <tdelocale.h>
+#include <tdeaboutdata.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kapplication.h>
-#include <kpopupmenu.h>
+#include <tdeapplication.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <kprogress.h>
 #include <kcolorbutton.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kseparator.h>
 
 // Local includes.
@@ -119,7 +119,7 @@ public:
         
     KColorButton *guideColorBt;
 
-    KAboutData   *aboutData;
+    TDEAboutData   *aboutData;
 
     Sidebar      *settingsSideBar;
 };
@@ -253,7 +253,7 @@ ImageGuideDlg::ImageGuideDlg(TQWidget* parent, TQString title, TQString name,
     d->settingsSideBar->loadViewState();
     
     // Reading splitter sizes here prevent flicker effect in dialog.
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup(d->name + TQString(" Tool Dialog"));
     if(config->hasKey("SplitterSizes"))
         d->splitter->setSizes(config->readIntListEntry("SplitterSizes"));
@@ -282,7 +282,7 @@ ImageGuideDlg::~ImageGuideDlg()
 void ImageGuideDlg::readSettings(void)
 {
     TQColor defaultGuideColor(TQt::red);
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup(d->name + TQString(" Tool Dialog"));
     d->guideColorBt->setColor(config->readColorEntry("Guide Color", &defaultGuideColor));
     d->guideSize->setValue(config->readNumEntry("Guide Width", 1));
@@ -292,7 +292,7 @@ void ImageGuideDlg::readSettings(void)
 
 void ImageGuideDlg::writeSettings(void)
 {
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup(d->name + TQString(" Tool Dialog"));
     config->writeEntry( "Guide Color", d->guideColorBt->color() );
     config->writeEntry( "Guide Width", d->guideSize->value() );
@@ -328,7 +328,7 @@ void ImageGuideDlg::setUserAreaWidget(TQWidget *w)
     d->settingsLayout->addMultiCellLayout(vLayout, 0, 0, 0, 0);
 }
 
-void ImageGuideDlg::setAboutData(KAboutData *about)
+void ImageGuideDlg::setAboutData(TDEAboutData *about)
 {
     d->aboutData = about;
     TQPushButton *helpButton = actionButton( Help );
@@ -428,7 +428,7 @@ void ImageGuideDlg::slotHelp()
     // else digiKam help. In this case, setHelp() method must be used to set anchor and handbook name.
 
     if (d->aboutData)
-        KApplication::kApplication()->invokeHelp(d->name, "digikam");
+        TDEApplication::kApplication()->invokeHelp(d->name, "digikam");
     else
         KDialogBase::slotHelp();
 }
