@@ -35,9 +35,9 @@
 
 // KDE includes.
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdialogbase.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
 #include <ksqueezedtextlabel.h>
 #include <kseparator.h>
 
@@ -422,11 +422,11 @@ void ImagePropertiesTab::setCurrentURL(const KURL& url)
     d->labelFolder->setText(url.directory());
 
     TQDateTime modifiedDate = fileInfo.lastModified();
-    str = KGlobal::locale()->formatDateTime(modifiedDate, true, true);
+    str = TDEGlobal::locale()->formatDateTime(modifiedDate, true, true);
     d->labelFileModifiedDate->setText(str);
 
-    str = TQString("%1 (%2)").arg(KIO::convertSize(fi.size()))
-                            .arg(KGlobal::locale()->formatNumber(fi.size(), 0));
+    str = TQString("%1 (%2)").arg(TDEIO::convertSize(fi.size()))
+                            .arg(TDEGlobal::locale()->formatNumber(fi.size(), 0));
     d->labelFileSize->setText(str);
 
     d->labelFileOwner->setText( TQString("%1 - %2").arg(fi.user()).arg(fi.group()) );
@@ -563,7 +563,7 @@ void ImagePropertiesTab::setCurrentURL(const KURL& url)
 
     if (photoInfo.dateTime.isValid())
     {
-        str = KGlobal::locale()->formatDateTime(photoInfo.dateTime, true, true);
+        str = TDEGlobal::locale()->formatDateTime(photoInfo.dateTime, true, true);
         d->labelPhotoDateTime->setText(str);
     }
     else
