@@ -39,7 +39,7 @@
 
 // KDE includes.
 
-#include <klocale.h>
+#include <tdelocale.h>
 
 // Local includes.
 
