@@ -49,25 +49,25 @@ extern "C"
 // KDE includes.
 
 #include <kcursor.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kstdaction.h>
-#include <kapplication.h>
-#include <kconfig.h>
-#include <klocale.h>
-#include <kfiledialog.h>
-#include <kmenubar.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
+#include <tdelocale.h>
+#include <tdefiledialog.h>
+#include <tdemenubar.h>
 #include <kimageio.h>
-#include <kaccel.h>
-#include <kdeversion.h>
-#include <kmessagebox.h>
-#include <kglobal.h>
+#include <tdeaccel.h>
+#include <tdeversion.h>
+#include <tdemessagebox.h>
+#include <tdeglobal.h>
 #include <kstandarddirs.h>
 #include <kiconloader.h>
-#include <kio/netaccess.h>
-#include <kio/job.h>
+#include <tdeio/netaccess.h>
+#include <tdeio/job.h>
 #include <kprotocolinfo.h>
-#include <kglobalsettings.h>
-#include <ktoolbar.h>
+#include <tdeglobalsettings.h>
+#include <tdetoolbar.h>
 #include <kstatusbar.h>
 #include <kprogress.h>
 
@@ -142,12 +142,12 @@ public:
 
     KURL                             lastOpenedDirectory;
 
-    KToggleAction                   *showBarAction;
+    TDEToggleAction                   *showBarAction;
 
-    KAction                         *openFilesInFolderAction;
-    KAction                         *fileOpenAction;
+    TDEAction                         *openFilesInFolderAction;
+    TDEAction                         *fileOpenAction;
 
-    KActionMenu                     *BCGAction;
+    TDEActionMenu                     *BCGAction;
 
     Digikam::ThumbBarView           *thumbBar;
     Digikam::ThumbBarItem           *currentItem;
@@ -162,10 +162,10 @@ ShowFoto::ShowFoto(const KURL::List& urlList)
 
     // -- Show splash at start ----------------------------
 
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("ImageViewer Settings");
-    KGlobal::dirs()->addResourceType("data", KGlobal::dirs()->kde_default("data") + "digikam");
-    KGlobal::iconLoader()->addAppDir("digikam");
+    TDEGlobal::dirs()->addResourceType("data", TDEGlobal::dirs()->kde_default("data") + "digikam");
+    TDEGlobal::iconLoader()->addAppDir("digikam");
 
     if(config->readBoolEntry("ShowSplash", true) && !kapp->isRestored())
     {
@@ -211,25 +211,25 @@ ShowFoto::ShowFoto(const KURL::List& urlList)
 
     if ( !m_imagePluginLoader->pluginLibraryIsLoaded("digikamimageplugin_core") )
     {
-        d->BCGAction = new KActionMenu(i18n("Brightness/Contrast/Gamma"), 0, 0, "showfoto_bcg");
+        d->BCGAction = new TDEActionMenu(i18n("Brightness/Contrast/Gamma"), 0, 0, "showfoto_bcg");
         d->BCGAction->setDelayed(false);
 
-        KAction *incGammaAction = new KAction(i18n("Increase Gamma"), 0, ALT+Key_G,
+        TDEAction *incGammaAction = new TDEAction(i18n("Increase Gamma"), 0, ALT+Key_G,
                                             TQT_TQOBJECT(this), TQT_SLOT(slotChangeBCG()),
                                             actionCollection(), "gamma_plus");
-        KAction *decGammaAction = new KAction(i18n("Decrease Gamma"), 0, ALT+SHIFT+Key_G,
+        TDEAction *decGammaAction = new TDEAction(i18n("Decrease Gamma"), 0, ALT+SHIFT+Key_G,
                                             TQT_TQOBJECT(this), TQT_SLOT(slotChangeBCG()),
                                             actionCollection(), "gamma_minus");
-        KAction *incBrightAction = new KAction(i18n("Increase Brightness"), 0, ALT+Key_B,
+        TDEAction *incBrightAction = new TDEAction(i18n("Increase Brightness"), 0, ALT+Key_B,
                                             TQT_TQOBJECT(this), TQT_SLOT(slotChangeBCG()),
                                             actionCollection(), "brightness_plus");
-        KAction *decBrightAction = new KAction(i18n("Decrease Brightness"), 0, ALT+SHIFT+Key_B,
+        TDEAction *decBrightAction = new TDEAction(i18n("Decrease Brightness"), 0, ALT+SHIFT+Key_B,
                                             TQT_TQOBJECT(this), TQT_SLOT(slotChangeBCG()),
                                             actionCollection(), "brightness_minus");
-        KAction *incContrastAction = new KAction(i18n("Increase Contrast"), 0, ALT+Key_C,
+        TDEAction *incContrastAction = new TDEAction(i18n("Increase Contrast"), 0, ALT+Key_C,
                                             TQT_TQOBJECT(this), TQT_SLOT(slotChangeBCG()),
                                             actionCollection(), "contrast_plus");
-        KAction *decContrastAction = new KAction(i18n("Decrease Contrast"), 0, ALT+SHIFT+Key_C,
+        TDEAction *decContrastAction = new TDEAction(i18n("Decrease Contrast"), 0, ALT+SHIFT+Key_C,
                                             TQT_TQOBJECT(this), TQT_SLOT(slotChangeBCG()),
                                             actionCollection(), "contrast_minus");
 
@@ -240,7 +240,7 @@ ShowFoto::ShowFoto(const KURL::List& urlList)
         d->BCGAction->insert(incGammaAction);
         d->BCGAction->insert(decGammaAction);
 
-        TQPtrList<KAction> bcg_actions;
+        TQPtrList<TDEAction> bcg_actions;
         bcg_actions.append( d->BCGAction );
         unplugActionList( "showfoto_bcg" );
         plugActionList( "showfoto_bcg", bcg_actions );
@@ -352,11 +352,11 @@ void ShowFoto::show()
 
     // Display application window.
 
-    KMainWindow::show();
+    TDEMainWindow::show();
 
     // Report errors from ICC repository path.
 
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     if(!d->validIccPath)
     {
         TQString message = i18n("<qt><p>The ICC profile path seems to be invalid.</p>"
@@ -407,13 +407,13 @@ void ShowFoto::setupConnections()
 
 void ShowFoto::setupUserArea()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("ImageViewer Settings");
 
     TQWidget* widget = new TQWidget(this);
     TQSizePolicy rightSzPolicy(TQSizePolicy::Preferred, TQSizePolicy::Expanding, 2, 1);
 
-    if(!config->readBoolEntry("HorizontalThumbbar", false)) //Qt::Vertical thumbbar layout
+    if(!config->readBoolEntry("HorizontalThumbbar", false)) // Vertical thumbbar layout
     {
         TQHBoxLayout *hlay = new TQHBoxLayout(widget);
         m_splitter        = new TQSplitter(widget);
@@ -428,7 +428,7 @@ void ShowFoto::setupUserArea()
         hlay->addWidget(m_splitter);
         hlay->addWidget(d->rightSidebar);
     }
-    else                                                     //Qt::Horizontal thumbbar layout
+    else                                                     // Horizontal thumbbar layout
     {
         m_splitter        = new TQSplitter(Qt::Horizontal, widget);
         TQWidget* widget2  = new TQWidget(m_splitter);
@@ -481,7 +481,7 @@ void ShowFoto::setupActions()
     d->fileOpenAction = KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(slotOpenFile()),
                         actionCollection(), "showfoto_open_file");
 
-    d->openFilesInFolderAction = new KAction(i18n("Open folder"),
+    d->openFilesInFolderAction = new TDEAction(i18n("Open folder"),
                                              "folder_image",
                                              CTRL+SHIFT+Key_O,
                                              TQT_TQOBJECT(this),
@@ -493,7 +493,7 @@ void ShowFoto::setupActions()
 
     // Extra 'View' menu actions ---------------------------------------------
 
-    d->showBarAction = new KToggleAction(i18n("Show Thumbnails"), 0,
+    d->showBarAction = new TDEToggleAction(i18n("Show Thumbnails"), 0,
                                          CTRL+Key_T,
                                          TQT_TQOBJECT(this), TQT_SLOT(slotToggleShowBar()),
                                          actionCollection(), "shofoto_showthumbs");
@@ -509,14 +509,14 @@ void ShowFoto::readSettings()
 {
     readStandardSettings();
 
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("ImageViewer Settings");
 
     d->showBarAction->setChecked(config->readBoolEntry("Show Thumbnails", true));
     slotToggleShowBar();
 
     d->lastOpenedDirectory.setPath( config->readEntry("Last Opened Directory",
-                                    KGlobalSettings::documentPath()) );
+                                    TDEGlobalSettings::documentPath()) );
 
     TQSizePolicy szPolicy(TQSizePolicy::Preferred, TQSizePolicy::Expanding, 2, 1);
     if(config->hasKey("Vertical Splitter Sizes") && d->vSplitter)
@@ -531,7 +531,7 @@ void ShowFoto::saveSettings()
 {
     saveStandardSettings();
 
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("ImageViewer Settings");
 
     config->writeEntry("Last Opened Directory", d->lastOpenedDirectory.path() );
@@ -549,7 +549,7 @@ void ShowFoto::applySettings()
 {
     applyStandardSettings();
 
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("ImageViewer Settings");
 
     // Current image deleted go to trash ?
@@ -561,7 +561,7 @@ void ShowFoto::applySettings()
     }
     else
     {
-        m_fileDeleteAction->setIcon("editdelete");
+        m_fileDeleteAction->setIcon("edit-delete");
         m_fileDeleteAction->setText(i18n("Delete File"));
     }
 
@@ -629,9 +629,9 @@ void ShowFoto::slotOpenURL(const KURL& url)
 
     TQString localFile;
 #if KDE_IS_VERSION(3,2,0)
-    KIO::NetAccess::download(url, localFile, this);
+    TDEIO::NetAccess::download(url, localFile, this);
 #else
-    KIO::NetAccess::download(url, localFile);
+    TDEIO::NetAccess::download(url, localFile);
 #endif
 
     m_canvas->load(localFile, m_IOFileSettings);
@@ -873,7 +873,7 @@ void ShowFoto::openFolder(const KURL& url)
 
     // Determine sort ordering for the entries from configuration setting:
 
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("ImageViewer Settings");
     int flag;
 
@@ -1113,9 +1113,9 @@ void ShowFoto::slotDeleteCurrentItem()
         }
         else
         {
-            KIO::Job* job = KIO::del( urlCurrent );
-            connect( job, TQT_SIGNAL(result( KIO::Job* )),
-                     TQT_TQOBJECT(this), TQT_SLOT(slotDeleteCurrentItemResult( KIO::Job*)) );
+            TDEIO::Job* job = TDEIO::del( urlCurrent );
+            connect( job, TQT_SIGNAL(result( TDEIO::Job* )),
+                     TQT_TQOBJECT(this), TQT_SLOT(slotDeleteCurrentItemResult( TDEIO::Job*)) );
         }
     }
     else
@@ -1124,16 +1124,16 @@ void ShowFoto::slotDeleteCurrentItem()
 
         if (!KProtocolInfo::isKnownProtocol(dest))
         {
-            dest = KGlobalSettings::trashPath();
+            dest = TDEGlobalSettings::trashPath();
         }
 
-        KIO::Job* job = KIO::move( urlCurrent, dest );
-        connect( job, TQT_SIGNAL(result( KIO::Job* )),
-                 TQT_TQOBJECT(this), TQT_SLOT(slotDeleteCurrentItemResult( KIO::Job*)) );
+        TDEIO::Job* job = TDEIO::move( urlCurrent, dest );
+        connect( job, TQT_SIGNAL(result( TDEIO::Job* )),
+                 TQT_TQOBJECT(this), TQT_SLOT(slotDeleteCurrentItemResult( TDEIO::Job*)) );
     }
 }
 
-void ShowFoto::slotDeleteCurrentItemResult( KIO::Job * job )
+void ShowFoto::slotDeleteCurrentItemResult( TDEIO::Job * job )
 {
     if (job->error() != 0)
     {
@@ -1190,7 +1190,7 @@ void ShowFoto::slideShow(bool startWithCurrent, Digikam::SlideShowSettings& sett
 {
     if (!d->thumbBar->countItems()) return;
 
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("ImageViewer Settings");
 
     settings.exifRotate = config->readBoolEntry("EXIF Rotate", true);
