@@ -95,7 +95,7 @@ public:
     };
 
     Action                 action;
-    TQMap<TQString,TQVariant> map; 
+    TQStringVariantMap map;
 };
 
 class CameraEvent : public TQCustomEvent
@@ -131,7 +131,7 @@ public:
 
     bool                   result;
     TQString                msg;
-    TQMap<TQString,TQVariant> map; 
+    TQStringVariantMap map;
 };
 
 class CameraControllerPriv
@@ -768,17 +768,17 @@ void CameraController::download(DownloadSettingsContainer downloadSettings)
     cmd->map.insert("folder", TQVariant(downloadSettings.folder));
     cmd->map.insert("file", TQVariant(downloadSettings.file));
     cmd->map.insert("dest", TQVariant(downloadSettings.dest));
-    cmd->map.insert("autoRotate", TQVariant(downloadSettings.autoRotate, 0));
-    cmd->map.insert("fixDateTime", TQVariant(downloadSettings.fixDateTime, 0));
+    cmd->map.insert("autoRotate", TQVariant(downloadSettings.autoRotate));
+    cmd->map.insert("fixDateTime", TQVariant(downloadSettings.fixDateTime));
     cmd->map.insert("newDateTime", TQVariant(downloadSettings.newDateTime));
-    cmd->map.insert("setPhotographerId", TQVariant(downloadSettings.setPhotographerId, 0));
+    cmd->map.insert("setPhotographerId", TQVariant(downloadSettings.setPhotographerId));
     cmd->map.insert("author", TQVariant(downloadSettings.author));
     cmd->map.insert("authorTitle", TQVariant(downloadSettings.authorTitle));
-    cmd->map.insert("setCredits", TQVariant(downloadSettings.setCredits, 0));
+    cmd->map.insert("setCredits", TQVariant(downloadSettings.setCredits));
     cmd->map.insert("credit", TQVariant(downloadSettings.credit));
     cmd->map.insert("source", TQVariant(downloadSettings.source));
     cmd->map.insert("copyright", TQVariant(downloadSettings.copyright));
-    cmd->map.insert("convertJpeg", TQVariant(downloadSettings.convertJpeg, 0));
+    cmd->map.insert("convertJpeg", TQVariant(downloadSettings.convertJpeg));
     cmd->map.insert("losslessFormat", TQVariant(downloadSettings.losslessFormat));
     d->cmdQueue.enqueue(cmd);
 }
@@ -800,7 +800,7 @@ void CameraController::lockFile(const TQString& folder, const TQString& file, bo
     cmd->action = CameraCommand::gp_lock;
     cmd->map.insert("folder", TQVariant(folder));
     cmd->map.insert("file", TQVariant(file));
-    cmd->map.insert("lock", TQVariant(lock, 0));
+    cmd->map.insert("lock", TQVariant(lock));
     d->cmdQueue.enqueue(cmd);
 }
 
