@@ -47,7 +47,7 @@
 // KDE includes.
 
 #include <kcursor.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 // Local includes.
 
@@ -646,7 +646,7 @@ void DImgInterface::saveAs(const TQString& fileName, IOFileSettingsContainer *io
     // Update Exif Document Name tag with the original file name.
     meta.setExifTagString("Exif.Image.DocumentName", getImageFileName());
 
-    // Update Exif Qt::Orientation tag if necessary.
+    // Update Exif Orientation tag if necessary.
     if( setExifOrientationTag )
         meta.setImageOrientation(DMetadata::ORIENTATION_NORMAL);
 
