@@ -30,10 +30,10 @@
 
 // KDE includes.
 
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
 
 // Local includes.
@@ -100,9 +100,9 @@ LightTableBar::LightTableBar(TQWidget* parent, int orientation, bool exifRotate)
 
     // -- Load rating Pixmap ------------------------------------------
 
-    KGlobal::dirs()->addResourceType("digikam_rating", KGlobal::dirs()->kde_default("data")
+    TDEGlobal::dirs()->addResourceType("digikam_rating", TDEGlobal::dirs()->kde_default("data")
                                      + "digikam/data");
-    TQString ratingPixPath = KGlobal::dirs()->findResourceDir("digikam_rating", "rating.png");
+    TQString ratingPixPath = TDEGlobal::dirs()->findResourceDir("digikam_rating", "rating.png");
     ratingPixPath += "/rating.png";
     d->ratingPixmap = TQPixmap(ratingPixPath);
 
@@ -167,12 +167,12 @@ void LightTableBar::contentsMouseReleaseEvent(TQMouseEvent *e)
 
     if (e->button() == Qt::RightButton)
     {
-        KPopupMenu popmenu(this);
+        TDEPopupMenu popmenu(this);
 
         if (item)
         {
-            popmenu.insertItem(SmallIcon("previous"), i18n("Show on left panel"), 10);
-            popmenu.insertItem(SmallIcon("next"), i18n("Show on right panel"), 11);
+            popmenu.insertItem(SmallIcon("go-previous"), i18n("Show on left panel"), 10);
+            popmenu.insertItem(SmallIcon("go-next"), i18n("Show on right panel"), 11);
             popmenu.insertItem(SmallIcon("editimage"), i18n("Edit"), 12);
 
             if (d->navigateByPair)
@@ -182,7 +182,7 @@ void LightTableBar::contentsMouseReleaseEvent(TQMouseEvent *e)
             }
 
             popmenu.insertSeparator();
-            popmenu.insertItem(SmallIcon("fileclose"), i18n("Remove item"), 13);
+            popmenu.insertItem(SmallIcon("window-close"), i18n("Remove item"), 13);
         }
 
         int totalItems = itemsURLs().count();
@@ -524,12 +524,12 @@ void LightTableBar::viewportPaintEvent(TQPaintEvent* e)
 
                         if (ltItem->isOnLeftPanel())
                         {
-                            TQPixmap lPix = SmallIcon("previous");
+                            TQPixmap lPix = SmallIcon("go-previous");
                             bitBlt(&tile, getMargin(), getMargin(), &lPix);
                         }
                         if (ltItem->isOnRightPanel())
                         {
-                            TQPixmap rPix = SmallIcon("next");
+                            TQPixmap rPix = SmallIcon("go-next");
                             bitBlt(&tile, tile.width() - getMargin() - rPix.width(), getMargin(), &rPix);
                         }
 
@@ -580,12 +580,12 @@ void LightTableBar::viewportPaintEvent(TQPaintEvent* e)
 
                         if (ltItem->isOnLeftPanel())
                         {
-                            TQPixmap lPix = SmallIcon("previous");
+                            TQPixmap lPix = SmallIcon("go-previous");
                             bitBlt(&tile, getMargin(), getMargin(), &lPix);
                         }
                         if (ltItem->isOnRightPanel())
                         {
-                            TQPixmap rPix = SmallIcon("next");
+                            TQPixmap rPix = SmallIcon("go-next");
                             bitBlt(&tile, tile.width() - getMargin() - rPix.width(), getMargin(), &rPix);
                         }
 
@@ -638,7 +638,7 @@ void LightTableBar::startDrag()
     imageIDs.append(item->info()->id());
     albumIDs.append(item->info()->albumID());
 
-    TQPixmap icon(DesktopIcon("image", 48));
+    TQPixmap icon(DesktopIcon("image-x-generic", 48));
     int w = icon.width();
     int h = icon.height();
 
@@ -766,9 +766,9 @@ void LightTableBar::contentsDropEvent(TQDropEvent *e)
 
 void LightTableBar::slotThemeChanged()
 {
-    KGlobal::dirs()->addResourceType("digikam_rating", KGlobal::dirs()->kde_default("data")
+    TDEGlobal::dirs()->addResourceType("digikam_rating", TDEGlobal::dirs()->kde_default("data")
                                      + "digikam/data");
-    TQString ratingPixPath = KGlobal::dirs()->findResourceDir("digikam_rating", "rating.png");
+    TQString ratingPixPath = TDEGlobal::dirs()->findResourceDir("digikam_rating", "rating.png");
     ratingPixPath += "/rating.png";
     d->ratingPixmap = TQPixmap(ratingPixPath);
 
