@@ -29,14 +29,14 @@
 
 #include <kkeydialog.h>
 #include <kedittoolbar.h>
-#include <kdeversion.h>
-#include <klocale.h>
-#include <kwin.h>
-#include <kmessagebox.h>
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeversion.h>
+#include <tdelocale.h>
+#include <twin.h>
+#include <tdemessagebox.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <kstatusbar.h>
-#include <kmenubar.h>
+#include <tdemenubar.h>
 
 // LibKDcraw includes.
 
@@ -87,7 +87,7 @@ bool LightTableWindow::lightTableWindowCreated()
 }
 
 LightTableWindow::LightTableWindow()
-                : KMainWindow(0, "lighttable", WType_TopLevel)
+                : TDEMainWindow(0, "lighttable", WType_TopLevel)
 {
     d = new LightTableWindowPriv;
     m_instance = this;
@@ -129,7 +129,7 @@ LightTableWindow::~LightTableWindow()
 
 void LightTableWindow::readSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("LightTable Settings");
 
     if(config->hasKey("Vertical Splitter Sizes"))
@@ -144,7 +144,7 @@ void LightTableWindow::readSettings()
 
 void LightTableWindow::writeSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("LightTable Settings");
     config->writeEntry("Vertical Splitter Sizes", d->vSplitter->sizes());
     config->writeEntry("Horizontal Splitter Sizes", d->hSplitter->sizes());
@@ -154,7 +154,7 @@ void LightTableWindow::writeSettings()
 
 void LightTableWindow::applySettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("LightTable Settings");
 
     d->autoLoadOnRightPanel  = config->readBoolEntry("Auto Load Right Panel",   true);
@@ -336,46 +336,46 @@ void LightTableWindow::setupActions()
                                    actionCollection(), "lighttable_forward");
     d->forwardAction->setEnabled(false);
 
-    d->firstAction = new KAction(i18n("&First"), "start",
-                                 KStdAccel::shortcut( KStdAccel::Home),
+    d->firstAction = new TDEAction(i18n("&First"), "go-first",
+                                 TDEStdAccel::shortcut( TDEStdAccel::Home),
                                  TQT_TQOBJECT(this), TQT_SLOT(slotFirst()),
                                  actionCollection(), "lighttable_first");
     d->firstAction->setEnabled(false);
 
-    d->lastAction = new KAction(i18n("&Last"), "finish",
-                                KStdAccel::shortcut( KStdAccel::End),
+    d->lastAction = new TDEAction(i18n("&Last"), "go-last",
+                                TDEStdAccel::shortcut( TDEStdAccel::End),
                                 TQT_TQOBJECT(this), TQT_SLOT(slotLast()),
                                 actionCollection(), "lighttable_last");
     d->lastAction->setEnabled(false);
 
-    d->setItemLeftAction = new KAction(i18n("On Left"), "previous",
+    d->setItemLeftAction = new TDEAction(i18n("On Left"), "go-previous",
                                        CTRL+Key_L, TQT_TQOBJECT(this), TQT_SLOT(slotSetItemLeft()),
                                        actionCollection(), "lighttable_setitemleft");
     d->setItemLeftAction->setEnabled(false);
     d->setItemLeftAction->setWhatsThis(i18n("Show item on left panel"));
 
-    d->setItemRightAction = new KAction(i18n("On Right"), "next",
+    d->setItemRightAction = new TDEAction(i18n("On Right"), "go-next",
                                        CTRL+Key_R, TQT_TQOBJECT(this), TQT_SLOT(slotSetItemRight()),
                                        actionCollection(), "lighttable_setitemright");
     d->setItemRightAction->setEnabled(false);
     d->setItemRightAction->setWhatsThis(i18n("Show item on right panel"));
 
-    d->editItemAction = new KAction(i18n("Edit"), "editimage",
+    d->editItemAction = new TDEAction(i18n("Edit"), "editimage",
                                        Key_F4, TQT_TQOBJECT(this), TQT_SLOT(slotEditItem()),
                                        actionCollection(), "lighttable_edititem");
     d->editItemAction->setEnabled(false);
 
-    d->removeItemAction = new KAction(i18n("Remove item from LightTable"), "fileclose",
+    d->removeItemAction = new TDEAction(i18n("Remove item from LightTable"), "window-close",
                                        CTRL+Key_K, TQT_TQOBJECT(this), TQT_SLOT(slotRemoveItem()),
                                        actionCollection(), "lighttable_removeitem");
     d->removeItemAction->setEnabled(false);
 
-    d->clearListAction = new KAction(i18n("Remove all items from LightTable"), "editshred",
+    d->clearListAction = new TDEAction(i18n("Remove all items from LightTable"), "editshred",
                                      CTRL+SHIFT+Key_K, TQT_TQOBJECT(this), TQT_SLOT(slotClearItemsList()),
                                      actionCollection(), "lighttable_clearlist");
     d->clearListAction->setEnabled(false);
 
-    d->fileDeleteAction = new KAction(i18n("Move to Trash"), "edittrash",
+    d->fileDeleteAction = new TDEAction(i18n("Move to Trash"), "edittrash",
                                      Key_Delete,
                                      TQT_TQOBJECT(this), TQT_SLOT(slotDeleteItem()),
                                      actionCollection(), "lighttable_filedelete");
@@ -385,14 +385,14 @@ void LightTableWindow::setupActions()
 
     // -- Standard 'View' menu actions ---------------------------------------------
 
-    d->syncPreviewAction = new KToggleAction(i18n("Synchronize"), "goto",
+    d->syncPreviewAction = new TDEToggleAction(i18n("Synchronize"), "goto",
                                             CTRL+SHIFT+Key_Y, TQT_TQOBJECT(this),
                                             TQT_SLOT(slotToggleSyncPreview()),
                                             actionCollection(), "lighttable_syncpreview");
     d->syncPreviewAction->setEnabled(false);
     d->syncPreviewAction->setWhatsThis(i18n("Synchronize preview from left and right panels"));
 
-    d->navigateByPairAction = new KToggleAction(i18n("By Pair"), "kcmsystem",
+    d->navigateByPairAction = new TDEToggleAction(i18n("By Pair"), "preferences-system",
                                             CTRL+SHIFT+Key_P, TQT_TQOBJECT(this),
                                             TQT_SLOT(slotToggleNavigateByPair()),
                                             actionCollection(), "lighttable_navigatebypair");
@@ -407,23 +407,23 @@ void LightTableWindow::setupActions()
                                              actionCollection(), "lighttable_zoomminus");
     d->zoomMinusAction->setEnabled(false);
 
-    d->zoomTo100percents = new KAction(i18n("Zoom to 100%"), "viewmag1",
+    d->zoomTo100percents = new TDEAction(i18n("Zoom to 100%"), "zoom-original",
                                        ALT+CTRL+Key_0,      // NOTE: Photoshop 7 use ALT+CTRL+0.
                                        TQT_TQOBJECT(this), TQT_SLOT(slotZoomTo100Percents()),
                                        actionCollection(), "lighttable_zoomto100percents");
 
-    d->zoomFitToWindowAction = new KAction(i18n("Fit to &Window"), "view_fit_window",
+    d->zoomFitToWindowAction = new TDEAction(i18n("Fit to &Window"), "view_fit_window",
                                            CTRL+SHIFT+Key_E, TQT_TQOBJECT(this), TQT_SLOT(slotFitToWindow()),
                                            actionCollection(), "lighttable_zoomfit2window");
 
     // Do not use std KDE action for full screen because action text is too large for app. toolbar.
-    d->fullScreenAction = new KToggleAction(i18n("Full Screen"), "window_fullscreen",
+    d->fullScreenAction = new TDEToggleAction(i18n("Full Screen"), "view-fullscreen",
                                             CTRL+SHIFT+Key_F, TQT_TQOBJECT(this),
                                             TQT_SLOT(slotToggleFullScreen()),
                                             actionCollection(), "lighttable_fullscreen");
     d->fullScreenAction->setWhatsThis(i18n("Toggle the window to full screen mode"));
 
-    d->slideShowAction = new KAction(i18n("Slideshow"), "slideshow", Key_F9,
+    d->slideShowAction = new TDEAction(i18n("Slideshow"), "slideshow", Key_F9,
                                      TQT_TQOBJECT(this), TQT_SLOT(slotToggleSlideShow()),
                                      actionCollection(),"lighttable_slideshow");
 
@@ -437,7 +437,7 @@ void LightTableWindow::setupActions()
 
     // -----------------------------------------------------------------------------------------
 
-    d->themeMenuAction = new KSelectAction(i18n("&Themes"), 0, actionCollection(), "theme_menu");
+    d->themeMenuAction = new TDESelectAction(i18n("&Themes"), 0, actionCollection(), "theme_menu");
     connect(d->themeMenuAction, TQT_SIGNAL(activated(const TQString&)),
             TQT_TQOBJECT(this), TQT_SLOT(slotChangeTheme(const TQString&)));
 
@@ -447,19 +447,19 @@ void LightTableWindow::setupActions()
     // -- Standard 'Help' menu actions ---------------------------------------------
 
 
-    d->donateMoneyAction = new KAction(i18n("Donate..."),
+    d->donateMoneyAction = new TDEAction(i18n("Donate..."),
                                        0, 0,
                                        TQT_TQOBJECT(this), TQT_SLOT(slotDonateMoney()),
                                        actionCollection(),
                                        "lighttable_donatemoney");
 
-    d->contributeAction = new KAction(i18n("Contribute..."),
+    d->contributeAction = new TDEAction(i18n("Contribute..."),
                                       0, 0,
                                       TQT_TQOBJECT(this), TQT_SLOT(slotContribute()),
                                       actionCollection(),
                                       "lighttable_contribute");
 
-    d->rawCameraListAction = new KAction(i18n("Supported RAW Cameras"),
+    d->rawCameraListAction = new TDEAction(i18n("Supported RAW Cameras"),
                                          "kdcraw",
                                          0,
                                          TQT_TQOBJECT(this),
@@ -476,22 +476,22 @@ void LightTableWindow::setupActions()
 
     // -- Rating actions ---------------------------------------------------------------
 
-    d->star0 = new KAction(i18n("Assign Rating \"No Stars\""), CTRL+Key_0,
+    d->star0 = new TDEAction(i18n("Assign Rating \"No Stars\""), CTRL+Key_0,
                           TQT_TQOBJECT(d->barView), TQT_SLOT(slotAssignRatingNoStar()),
                           actionCollection(), "lighttable_ratenostar");
-    d->star1 = new KAction(i18n("Assign Rating \"One Star\""), CTRL+Key_1,
+    d->star1 = new TDEAction(i18n("Assign Rating \"One Star\""), CTRL+Key_1,
                           TQT_TQOBJECT(d->barView), TQT_SLOT(slotAssignRatingOneStar()),
                           actionCollection(), "lighttable_rateonestar");
-    d->star2 = new KAction(i18n("Assign Rating \"Two Stars\""), CTRL+Key_2,
+    d->star2 = new TDEAction(i18n("Assign Rating \"Two Stars\""), CTRL+Key_2,
                           TQT_TQOBJECT(d->barView), TQT_SLOT(slotAssignRatingTwoStar()),
                           actionCollection(), "lighttable_ratetwostar");
-    d->star3 = new KAction(i18n("Assign Rating \"Three Stars\""), CTRL+Key_3,
+    d->star3 = new TDEAction(i18n("Assign Rating \"Three Stars\""), CTRL+Key_3,
                           TQT_TQOBJECT(d->barView), TQT_SLOT(slotAssignRatingThreeStar()),
                           actionCollection(), "lighttable_ratethreestar");
-    d->star4 = new KAction(i18n("Assign Rating \"Four Stars\""), CTRL+Key_4,
+    d->star4 = new TDEAction(i18n("Assign Rating \"Four Stars\""), CTRL+Key_4,
                           TQT_TQOBJECT(d->barView), TQT_SLOT(slotAssignRatingFourStar()),
                           actionCollection(), "lighttable_ratefourstar");
-    d->star5 = new KAction(i18n("Assign Rating \"Five Stars\""), CTRL+Key_5,
+    d->star5 = new TDEAction(i18n("Assign Rating \"Five Stars\""), CTRL+Key_5,
                           TQT_TQOBJECT(d->barView), TQT_SLOT(slotAssignRatingFiveStar()),
                           actionCollection(), "lighttable_ratefivestar");
 
@@ -504,7 +504,7 @@ void LightTableWindow::setupActions()
 
 void LightTableWindow::setupAccelerators()
 {
-    d->accelerators = new KAccel(this);
+    d->accelerators = new TDEAccel(this);
 
     d->accelerators->insert("Exit fullscreen", i18n("Exit Fullscreen mode"),
                     i18n("Exit fullscreen viewing mode"),
@@ -956,7 +956,7 @@ void LightTableWindow::slotDeleteItem(ImageInfo* info)
     if (!palbum)
         return;
 
-    // Provide a digikamalbums:// URL to KIO
+    // Provide a digikamalbums:// URL to TDEIO
     KURL kioURL  = info->kurlForKIO();
     KURL fileURL = u;
 
@@ -1261,7 +1261,7 @@ void LightTableWindow::slotFitToWindow()
 
 void LightTableWindow::slotToggleSlideShow()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("ImageViewer Settings");
     bool startWithCurrent = config->readBoolEntry("SlideShowStartCurrent", false);
 
@@ -1345,11 +1345,11 @@ void LightTableWindow::slotToggleFullScreen()
         topDock()->show();
         bottomDock()->show();
 
-        TQObject* obj = child("ToolBar","KToolBar");
+        TQObject* obj = child("ToolBar","TDEToolBar");
 
         if (obj)
         {
-            KToolBar* toolBar = static_cast<KToolBar*>(TQT_TQWIDGET(obj));
+            TDEToolBar* toolBar = static_cast<TDEToolBar*>(TQT_TQWIDGET(obj));
 
             if (d->fullScreenAction->isPlugged(toolBar) && d->removeFullScreenButton)
                 d->fullScreenAction->unplug(toolBar);
@@ -1385,11 +1385,11 @@ void LightTableWindow::slotToggleFullScreen()
         rightDock()->hide();
         bottomDock()->hide();
 
-        TQObject* obj = child("ToolBar","KToolBar");
+        TQObject* obj = child("ToolBar","TDEToolBar");
 
         if (obj)
         {
-            KToolBar* toolBar = static_cast<KToolBar*>(TQT_TQWIDGET(obj));
+            TDEToolBar* toolBar = static_cast<TDEToolBar*>(TQT_TQWIDGET(obj));
 
             if (d->fullScreenHideToolBar)
             {
@@ -1441,8 +1441,8 @@ void LightTableWindow::slotEscapePressed()
 
 void LightTableWindow::showToolBars()
 {
-    TQPtrListIterator<KToolBar> it = toolBarIterator();
-    KToolBar* bar;
+    TQPtrListIterator<TDEToolBar> it = toolBarIterator();
+    TDEToolBar* bar;
 
     for( ; it.current()!=0L ; ++it)
     {
@@ -1457,8 +1457,8 @@ void LightTableWindow::showToolBars()
 
 void LightTableWindow::hideToolBars()
 {
-    TQPtrListIterator<KToolBar> it = toolBarIterator();
-    KToolBar* bar;
+    TQPtrListIterator<TDEToolBar> it = toolBarIterator();
+    TDEToolBar* bar;
 
     for( ; it.current()!=0L ; ++it)
     {
@@ -1471,7 +1471,7 @@ void LightTableWindow::hideToolBars()
     }
 }
 
-void LightTableWindow::plugActionAccel(KAction* action)
+void LightTableWindow::plugActionAccel(TDEAction* action)
 {
     if (!action)
         return;
@@ -1484,19 +1484,19 @@ void LightTableWindow::plugActionAccel(KAction* action)
                     TQT_SLOT(activate()));
 }
 
-void LightTableWindow::unplugActionAccel(KAction* action)
+void LightTableWindow::unplugActionAccel(TDEAction* action)
 {
     d->accelerators->remove(action->text());
 }
 
 void LightTableWindow::slotDonateMoney()
 {
-    KApplication::kApplication()->invokeBrowser("http://www.digikam.org/?q=donation");
+    TDEApplication::kApplication()->invokeBrowser("http://www.digikam.org/?q=donation");
 }
 
 void LightTableWindow::slotContribute()
 {
-    KApplication::kApplication()->invokeBrowser("http://www.digikam.org/?q=contrib");
+    TDEApplication::kApplication()->invokeBrowser("http://www.digikam.org/?q=contrib");
 }
 
 void LightTableWindow::slotEditKeys()
@@ -1508,7 +1508,7 @@ void LightTableWindow::slotEditKeys()
 
 void LightTableWindow::slotConfToolbars()
 {
-    saveMainWindowSettings(KGlobal::config(), "LightTable Settings");
+    saveMainWindowSettings(TDEGlobal::config(), "LightTable Settings");
     KEditToolbar dlg(factory(), this);
 
     connect(&dlg, TQT_SIGNAL(newToolbarConfig()),
@@ -1519,7 +1519,7 @@ void LightTableWindow::slotConfToolbars()
 
 void LightTableWindow::slotNewToolbarConfig()
 {
-    applyMainWindowSettings(KGlobal::config(), "LightTable Settings");
+    applyMainWindowSettings(TDEGlobal::config(), "LightTable Settings");
 }
 
 void LightTableWindow::slotSetup()
